@@ -48,7 +48,7 @@ fn channels_to_commands(channels: &[String], subscribe: bool) -> Vec<String> {
 
 fn on_misc_msg(msg: &str) -> MiscMessage {
     if msg == "pong" {
-        return MiscMessage::Misc;
+        return MiscMessage::Pong;
     }
     let obj = serde_json::from_str::<HashMap<String, Value>>(&msg).unwrap();
 
