@@ -61,7 +61,7 @@ fn channels_to_commands(channels: &[String], subscribe: bool) -> Vec<String> {
 fn on_misc_msg(msg: &str) -> MiscMessage {
     if msg.contains(r#"action":"PING"#) {
         debug!("Received {} from {}", msg, EXCHANGE_NAME);
-        MiscMessage::Misc
+        MiscMessage::Pong
     } else {
         MiscMessage::Normal
     }
